# Biogeme

Biogeme is an open source freeware designed for the maximum likelihood estimation of parametric models in general, with a special emphasis on discrete choice models.

## Install
Biogeme requires Python >= 3.8 and can be installed [from PyPI](https://pypi.org/project/biogeme/).

`pip install biogeme`

Installing Biogeme from source can be done after cloning the repository with the following command executed in the directory where the file `setup.py`is located:

`pip install -ve .`

## Documentation
Further documentation is available on https://biogeme.epfl.ch/
